@@ -47,7 +47,7 @@ TA.plot <-
   ## -------------------------------------------------------------------------
   ## Author: Martin Maechler, Date: Dec 92 / Nov.93;  for R: 1999/2000
   if(missing(main)) {
-    call <- lm.res $ call
+    call <- getCall(lm.res)
     if(is.call(call[["formula"]]) && any(c("lm", "aov") == call[[1]]))
       call <- call[["formula"]]
     else {  #-- only formula part; no extra  'data ='
@@ -78,8 +78,9 @@ TA.plot <-
       n.plot(fit, res, nam = labels, xlab = xlab, main = main, ...)
   } else {
       yl <- "Residuals"
-      if(!is.null(lm.res$weights) &&
-         any(abs(lm.res$resid- res) > 1e-6*mad(res)))
+      ## FIXME $weights, $resid -- not portable (e.g., to lmer obj!) ==> use extractors?
+      if(is.list(lm.res) && !is.null(lm.res$weights) && is.numeric(res0 <- lm.res$resid) &&
+         any(abs(res0 - res) > 1e-6*mad(res)))
           yl <- paste("WEIGHTED", yl)
       n.plot(fit, res, nam = labels, xlab = xlab, ylab = yl, main = main, ...)
   }
@@ -92,8 +93,8 @@ TA.plot <-
   m.line <- if(par("mfg")[4]==1) .2+ p.mgp[1] else
                               max(p.mgp[1] - .2*lo.cex, sum(p.mgp)/2)
   if(show.2sigma) {
-    s2 <- c(-2,2) * mad(res, center=0)
-    rr <- range(res)
+    s2 <- c(-2,2) * mad(res, center=0, na.rm=TRUE) # NA's possible in residuals
+    rr <- range(res, na.rm=TRUE)
     if(s2[1] < rr[1] || s2[2] > rr[2])
       mtext(paste("2 sigma = ", format(s2[2])),
 	    side= 1, line= m.line, adj = 0, cex= lo.cex)
@@ -105,8 +106,14 @@ TA.plot <-
     if(!is.list(parSmooth)) stop("`parSmooth' must be a list")
     ##-- lo.iter: idea of Werner Stahel:  no robustness for 'glm'  residuals
     if (is.null(lo.iter))
-      lo.iter <- if(inherits(lm.res, "glm")&& lm.res$family[1]!="Gaussian")
+      lo.iter <- if(inherits(lm.res, "glm") && family(lm.res)$family[1] != "Gaussian")
 	0  else  3
+    if(anyNA(res) && anyNA(fit)) {
+        i.ok <- !is.na(res) & !is.na(fit)
+        res <- res[i.ok]
+        fit <- fit[i.ok]
+        n <- sum(i.ok)
+    }
     f <- max(0.2, 1.25 * n^-.2) #'-- Martin's very empirical formula...
     rlow <- lowess(fit, res, f = f, iter = lo.iter)
     do.call("lines",c(rlow, parSmooth))
