@@ -13,6 +13,9 @@
 ### ___Note___ we have some of these headers __MESS__
 ### But we leave it because of RCS {rather dismantle everything into 4-6 pieces
 
+## A fast substitute for structure() *when* we don't need to special case for factor, .Dim, ...
+struct <- function(x, ...) `attributes<-`(x, c(attributes(x), list(...)))
+
 ##-#### Vector, Matrix (or higher Array) stuff ########
 ##-###  -------------------------------------- ########
 
@@ -235,6 +238,8 @@ paste.vec <- function(name, digits = options()$digits)
 }
 signi <- function(x, digits = 6) round(x, digits - trunc(log10(abs(x))))
 
+##' NB:  Since ~ R 3.3.0 (May 2016),  use base R's "new"   strrep(x, times)  instead
+
 repChar <- function(char, no) paste(rep.int(char, no), collapse = "")
 ## correct, but slower than the next one:
 bl.string <- function(no) repChar(" ", no)
@@ -466,6 +471,20 @@ strcodes <- function(x, table = chars8bit(1:255))
 ## S-PLUS has  AsciiToInt() officially, and   ichar() in  library(examples):
 AsciiToInt <- ichar <- function(strings) unname(unlist(strcodes(strings)))
 
+helppdf <- function(topic, viewer = getOption("pdfviewer"), quiet = !interactive(),
+                    ...) {
+    if(!tryCatch(is.character(topic) && length(topic) == 1L,
+		 error = function(e) FALSE))
+	topic <- deparse1(substitute(topic))
+    hh <- help(topic, help_type = "pdf", ...)
+    pdfile <- with(attributes(hh), paste(topic, type, sep="."))
+    ## almost all rendering & pdf creation happens here:
+    print(hh, msg=!quiet)# utils:::print.help_files_with_topic() |--> .show_help_on_topic_offline()
+    if(length(viewer))
+	system(paste(viewer, pdfile), wait = FALSE)
+    ans <- file.path(getwd(), pdfile)
+    if(quiet) invisible(ans) else ans
+}
 
 
 
@@ -548,8 +567,8 @@ rDatetime <- function(n, min = "1900-01-01", max = "2100-12-31") {
         max <- as.POSIXct(max)
     else stop("'max' must be string (coercable to \"POSIXct\") or \"POSIXt\" object")
     stopifnot(length(min) == 1, length(max) == 1)
-    structure(runif(n, as.numeric(min), as.numeric(max)),
-              class = c("POSIXct", "POSIXt"), tzone = "")
+    struct(runif(n, as.numeric(min), as.numeric(max)),
+           class = c("POSIXct", "POSIXt"), tzone = "")
 }
 
 ###
@@ -1006,7 +1025,7 @@ prt.DEBUG <- function(..., LEVEL = 1) {
 ## --> ../man/read.org.table.Rd
 read.org.table <- function(file, header = TRUE, skip = 0,
                            encoding = "native", fileEncoding = "",
-                           text, ...) {
+                           text, quiet=FALSE, ...) {
     ## file - text   handling --- cut'n'paste from read.table()'s header
     if (missing(file) && !missing(text)) {
 	file <- textConnection(text, encoding = "UTF-8")
@@ -1042,8 +1061,18 @@ read.org.table <- function(file, header = TRUE, skip = 0,
     }
     ## drop empty lines at end only
     while(grepl("^ *$", tail(ll, 1L))) ll <- ll[-length(ll)]
+    nent <- count.fields(textConnection(ll), sep="|")
+    ok <- nent == (p <- length(col.names))
+    nrows <- if(all(ok)) length(ok)
+             else match(FALSE, ok) - 1L # 1..n, where n+1 contains the first non-match
+    if("nrows" %in% ...names())
+        nrows <- min(nrows, list(...)$nrows)
+    else if(!quiet && nrows < 0.95*length(nent))
+        message(
+            sprintf("Will read the first %d rows (of each %d columns) of %d (non-empty non-header) lines",
+                    nrows, p, length(nent)))
     f.ll <- textConnection(ll)# , encoding = "UTF-8"  is *NOT* good
     on.exit(close(f.ll))
     read.table(f.ll, header=FALSE, sep = "|",
-               col.names = col.names, ...) # , encoding = "UTF-8" *not* good
+               col.names = col.names, nrows=nrows, ...) # , encoding = "UTF-8" *not* good
 }
